/*
  Example for Stepper 4 Click

  Date          : August 2017
  Author        : Irena Blagojevic

  Test configuration dsPIC :
    
  MCU                : P33FJ256GP710A
  Dev. Board         : EasyPIC Fusion v7
  dsPIC Compiler ver : v.7.1.0

  Description :

  Demonstrates how to use Stepper 4 click to move a stepper motor. First
  the speed is set, given in number of steps per revolution. Afterwards
  the motor is moved using STEPPER_step function, passing it the number
  of desired steps. If that number is negative, the motor moves CCW,
  otherwise it moves CW.

*/

#include "MIKROBUS_framework.h"
#include "__STEPPER_Driver.h"

void InitTimer2_3()
{
    T2CON         = 0x00;
    T3CON         = 0x0;
    TMR2          = 0;
    TMR3          = 0;
    T3IE_bit      = 1;
    T3IF_bit      = 0;
    T3IP_0_bit    = 1;
    T3IP_1_bit    = 1;
    T3IP_2_bit    = 1;
    PR3           = 0;
    PR2           = 400;
    T2CONbits.TON = 1;
    T2CONbits.T32 = 1;
}

void systemInit()
{
    STEPPER_GPIOmap( MIKROBUS1_setAN, MIKROBUS1_setCS, MIKROBUS1_setPWM,
                     MIKROBUS1_setRST, MIKROBUS1_setINT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_AN_PIN, GPIO_OUTPUT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_CS_PIN, GPIO_OUTPUT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_PWM_PIN, GPIO_OUTPUT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_RST_PIN, GPIO_OUTPUT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_INT_PIN, GPIO_OUTPUT );
    
    InitTimer2_3();
}

void Stepper_4_Init()
{
    STEPPER_init( 200, 100 );

    STEPPER_setAcc( 5 );
    STEPPER_setDec( 5 );
}

void Stepper_4_Task()
{
    STEPPER_setSpeed( 200 );
    STEPPER_step( 400 );
    Delay_ms( 200 );
    STEPPER_setSpeed( 100 );
    STEPPER_step( -200 );
}

void main()
{
    systemInit();
    Stepper_4_Init();

    Stepper_4_Task();
}

void Timer2_3Interrupt() iv IVT_ADDR_T3INTERRUPT
{
    T3IF_bit = 0;
    STEPPER_handler();
}
